==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/style.php <==
<?php
header('Content-Type: text/css; charset=utf-8');
?>
body {
	color: black; background-color: white;
	margin-top: 0%; margin-bottom: 0%;
	margin-left: 1%; margin-right: 1%;
	padding-left: 1%; padding-right: 1%;
	border-width: 1px;
	border-style: solid;
	border-color: #888888;
}
blockquote {
	color: inherit; background-color: #f6f6f6;
	border-color: #999999; border-style: dotted;
	border-width: 1px;
}
hr {
	display: none;
}
address {
	font-size: 75%;
}
#page {
}
#header {
	padding: 1%;
}
#header.default, #header.album, #header.users, #header.about {
	color: white; background-color: #6C8CA5;
}
#header.user_timeline, #header.friends_timeline, #header.entry, #header.favours {
	color: white; background-color: #D07C7A;
}
#header.keyword_timeline, #header.keywords, #header.keyword_users {
	color: white; background-color: #7BA86D;
}
#header.coco-ready, #header.coco-result {
  color: white; background-color: #77B4F1;
}
#header {
}
.header {
  border-bottom-style: solid; border-bottom-width: 1px;
  border-color: #999999;
  color: black; background-color: white;
  font-size: 75%; text-align: right;
}
.header-greeter {
  margin-right: 3%;
}
.header-login {
  margin-left: 3%;
}
#index-head {
}
.head1 {
}
.caption {
}
#index-contents {
	border: none;
}
.post-result, .oauth-res {
  color: black; background-color: #f6f6f6;
}
.contents {
	border-color: #999999; border-top-style: solid;
	border-top-width: 1px;
}
.index-content {
}
.content {
}
#entries-index-head {
	color: white; background-color: #6C8CA5;
}
a:link.entries {
	color: #43647C; background-color: transparent;
}
a:visited.entries {
	color: #43647C; background-color: transparent;
}
#users-index-head {
	color: white; background-color: #D07C7A;
}
a:link.user,a:visited.user {
	color: #833B55; background-color: transparent;
}
#keywords-index-head {
	color: white; background-color: #7BA86D;
}
a:link.keyword {
	color: #467237; background-color: transparent;
}
a:visited.keyword {
	color: #467237; background-color: transparent;
}
#footer {
	border-color: #999999; border-top-style: solid;
	border-top-width: 1px;
}

#entries-head {
}
.external-link {
}
.generic-link {
}
.image-link {
}

.post-box {
}
#post-keyword {
	font-size: 100%;
	width: 99%; height: auto;
}
#post-text {
	font-size: 100%;
	width: 99%; height: auto;
}
#post-haiku, #post-from {
	vertical-align: middle;
}
#post-from {
  width: 6em;
}
.entry, .users-list, .geo-result, .coco-search, .hateb-form, .to-amazon {
	border-color: #999999; border-bottom-style: solid;
	border-bottom-width: 1px;
	margin: 0; 
	padding-top: 1%;padding-bottom: 1%;
}
.entry-head {
	font-weight: bold;
}
.entry-body {
<?php
if (!preg_match('/.*up\.browser.*/ui',$_SERVER['HTTP_USER_AGENT'])){
	echo "line-height: 1.25;\n";
}
?>
}
.star-form {
	display: inline;
}
a:link.hatena-id {
	color: #833B55; background-color: transparent;
}
a:visited.hatena-id {
	color: #833B55; background-color: transparent;
}
.add-star-button {
	color: #327896; background-color: inherit;
<?php
if (!preg_match('/.*netfront.*/ui', $_SERVER['HTTP_USER_AGENT']))
	echo "\tborder-style: solid; border-color: #327896; border-width: 1px;\n";
?>
}
.hateb-form {
  margin: 1%;
}
#bcomment {
  width: 75%; height: auto;
}
#post-hateb {
  color: #1742CE; background-color: white;
  width: 10%; height: auto; font-weight: bold;
<?php
if (!preg_match('/.*netfront.*/ui', $_SERVER['HTTP_USER_AGENT']))
	echo "\tborder-style: solid; border-color:#1742CE ; border-width: 1px;\n";
?>
}
.hatena-star a:link, .hatena-star a:visited{
	color: #b88606; background-color: transparent;
}
.dating, .sname, .entry-head {
	color: #555555; background-color: transparent;
}
.reply {
	color: #555555; background-color: transparent;
}
a:link.replying,a:visited.replying {
	color: #833B55; background-color: transparent;
}
a:link.see-more {
	color: #833B55; background-color: transparent;
}
a:visited.see-more {
	color: #833B55; background-color: transparent;
}
.to-original-link {
}
.navigation-menu {
	list-style-type: none;
	margin-left: 0; margin-right: 0;
	padding: 0; padding-right: 0;
	padding-top: 0.2em; padding-bottom: 0.5em;
	font-family: monospace;
}
.navigation-menu li {
<?php
if (!preg_match('/.*up\.browser.*/ui',$_SERVER['HTTP_USER_AGENT'])){
	echo "line-height: 2.0;\n";
}
?>
}
a:link.navigation-link {
	color: #43647C; background-color: transparent;
}
a:visited.navigation-link {
	color: #43647C; background-color: transparent;
}
.access-key {
	text-decoration: underline;
}
#about-head {
}
.users-list dd, .users-list dt {
  display: inline;
}
.users-list dt {
  font-weight: bold;
}
.users-list dd {
  margin-left: 1px; padding-left: 1px;
}
.credit {
  font-size: 75%;
}

==> yanmah2-1.8-noarch.zip: yanmah2-1.8-noarch/style.php <==
<?php
header('Content-Type: text/css; charset=utf-8');
?>
body {
	color: black; background-color: white;
	margin-top: 0%; margin-bottom: 0%;
	margin-left: 1%; margin-right: 1%;
	padding-left: 1%; padding-right: 1%;
	border-width: 1px;
	border-style: solid;
	border-color: #888888;
}
blockquote {
	color: inherit; background-color: #f6f6f6;
	border-color: #999999; border-style: dotted;
	border-width: 1px;
}
hr {
	display: none;
}
address {
	font-size: 75%;
}
#page {
}
#header {
	padding: 1%;
}
#header.default, #header.album, #header.users, #header.about {
	color: white; background-color: #6C8CA5;
}
#header.user_timeline, #header.friends_timeline, #header.entry, #header.favours {
	color: white; background-color: #D07C7A;
}
#header.keyword_timeline, #header.keywords, #header.keyword_users {
	color: white; background-color: #7BA86D;
}
#header.coco-ready, #header.coco-result {
  color: white; background-color: #77B4F1;
}
#header {
}
#com-hdr {
  border-bottom-style: solid; border-bottom-width: 1px;
  border-color: #999999;
  color: black; background-color: white;
  font-size: 90%; text-align: right;
}
#com-ftr {
  border-top-style: solid; border-top-width: 1px;
  border-color: #999999;
  color: black; background-color: white;
  font-size: 90%; text-align: right;
}
.header-log, .ftr-cnf {
  margin-right: 3%;
}
.to-bottom, to-top {
  margin-left: 3%;
}
#index-head {
}
.head1 {
}
.caption {
  display: inline;
  font-size: 80%;
}
#index-contents {
	border: none;
}
.post-result, .oauth-res {
  color: black; background-color: #d6e6ff;
  margin: 1%; padding: 1%;
}
.contents {
	border-color: #999999; border-top-style: solid;
	border-top-width: 1px;
}
.contents ul, .cnf-blk, .cnf-blk ul {
  line-height: 1.25em;
}
.index-content {
}
.content {
}
#entries-index-head {
	color: white; background-color: #6C8CA5;
}
a:link.entries {
	color: #43647C; background-color: transparent;
}
a:visited.entries {
	color: #43647C; background-color: transparent;
}
#users-index-head {
	color: white; background-color: #D07C7A;
}
a:link.user,a:visited.user {
	color: #833B55; background-color: transparent;
}
#keywords-index-head {
	color: white; background-color: #7BA86D;
}
a:link.keyword {
	color: #467237; background-color: transparent;
}
a:visited.keyword {
	color: #467237; background-color: transparent;
}
#footer {
	border-color: #999999; border-top-style: solid;
	border-top-width: 1px;
}

#entries-head {
}
.external-link {
}
.generic-link {
}
.image-link {
}

.post-box {
}
#post-keyword {
	font-size: 100%;
	width: 99%; height: auto;
}
#post-text {
	font-size: 100%;
	width: 99%; height: 4em;
}
#post-haiku, #post-from {
	vertical-align: middle;
}
#post-from {
  width: 6em;
}
.entry, .users-list, .geo-result, .coco-search, .hateb-form, .to-amazon, .cnf-blk {
	border-color: #999999; border-bottom-style: solid;
	border-bottom-width: 1px;
	margin: 0; 
	padding-top: 1%;padding-bottom: 1%;
}
.entry img {
  max-width: 100%; max-height: 16em;
}
.entry-head {
	font-weight: bold;
}
.user-icon {
  height: 1em; width: 1em;
}
.entry-body {
<?php
if (!preg_match('/.*up\.browser.*/ui',$_SERVER['HTTP_USER_AGENT'])){
	echo "line-height: 1.25em;\n";
}
?>
}
.star-form {
	display: inline;
}
a:link.hatena-id {
	color: #833B55; background-color: transparent;
}
a:visited.hatena-id {
	color: #833B55; background-color: transparent;
}
.add-star-button {
  color: #327896; background-color: white;
  border-style: solid; border-color: #327896; border-width: 1px;
}
.hateb-form {
  margin: 1%;
}
#bcomment {
  width: 75%; height: auto;
}
#post-hateb {
  color: #1742CE; background-color: white;
  width: 10%; height: auto; font-weight: bold;
  border-style: solid; border-color:#1742CE ; border-width: 1px;
}
.hatena-star a:link, .hatena-star a:visited{
	color: #b88606; background-color: transparent;
}
.dating, .sname, .entry-head {
	color: #555555; background-color: transparent;
}
.reply {
	color: #555555; background-color: transparent;
}
a:link.replying,a:visited.replying {
	color: #833B55; background-color: transparent;
}
a:link.see-more {
	color: #833B55; background-color: transparent;
}
a:visited.see-more {
	color: #833B55; background-color: transparent;
}
.to-original-link {
}
#navigation-menu {
	list-style-type: none;
	margin-left: 0; margin-right: 0;
	padding: 0; padding-right: 0;
	padding-top: 0.2em; padding-bottom: 0.5em;
	font-size: 100%;
}
#navigation-menu li {
<?php
if (!preg_match('/.*up\.browser.*/ui',$_SERVER['HTTP_USER_AGENT'])){
	echo "line-height: 2.0;\n";
}
?>
}
a:link.navigation-link {
	color: #43647C; background-color: transparent;
}
a:visited.navigation-link {
	color: #43647C; background-color: transparent;
}
.access-key {
	text-decoration: underline;
}
#about-head {
}
.users-list dd, .users-list dt {
  display: inline;
}
.users-list dt {
  font-weight: bold;
}
.users-list dd {
  margin-left: 1px; padding-left: 1px;
}
.credit {
  font-size: 75%;
}
